# Python LED Strip Bluetooth Controller API

Compatible with MELK devices.

- [Read the Docs](https://python-bt-led-strip.readthedocs.io/)
- Code ~copied~ inspired by [dave-code-ruiz/elkbledom](https://github.com/dave-code-ruiz/elkbledom/) implemented with [bleak](https://github.com/hbldh/bleak)
- Developers
  - [Douglas Paz](https://github.com/dougppaz/)
